@@ -91,7 +91,8 @@ class AcsClient:
             credential=None,
             debug=False,
             verify=None,
-            pool_size=10
+            pool_size=10,
+            proxy=None
     ):
         """
         constructor for AcsClient
@@ -140,6 +141,8 @@ class AcsClient:
         else:
             self._retry_policy = retry_policy.NO_RETRY_POLICY
 
+        self.proxy = proxy
+
     def get_region_id(self):
         return self._region_id
 
@@ -280,7 +283,9 @@ class AcsClient:
             request.trans_to_acs_request()
 
         signer = self._signer if specific_signer is None else specific_signer
-        header, url = signer.sign(self._region_id, request)
+        header = request.get_headers()
+        signed_header, url = signer.sign(self._region_id, request)
+        header.update(signed_header)
 
         base = self.user_agent_header()
 
@@ -306,7 +311,8 @@ class AcsClient:
             read_timeout=read_timeout,
             connect_timeout=connect_timeout,
             verify=self.get_verify(),
-            session=self.session
+            session=self.session,
+            proxy=self.proxy
         )
         if body_params:
             response.set_content(body, "utf-8", request.get_headers().get('Content-Type'))
